==> v0.3.0.tar.gz: siyuan/README_en_US.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>When one drinks water, one must not forget where it comes from</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Release Date" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release-date/siyuan-note/siyuan.svg?style=flat-square&color=99CCFF"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README.md">中文</a>
</p>

## 💡 Introduction

SiYuan is a desktop Markdown Block-Reference and Bidirectional-Link note-taking application, supports Windows, Mac and Linux, can be used directly on the browser, and supports mobile-end adaptation.

Welcome to [SiYuan Official Discussion Forum](https://ld246.com/tag/siyuan) to learn more.

![desktop.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/desktop.png)

![mobile.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/mobile.png)

## ✨  Features

* **Born for Markdown**
  * Support Instant Rendering, users familiar with Typora should not be unfamiliar, in theory this is the most elegant Markdown editing method
  * Support mathematical formulas, charts, flowcharts, Gantt charts, timing charts, staffs, etc.
  * Paste HTML automatically converted to Markdown
  * Configure Markdown to analyze detailed rendering parameters
* Content block
   * Block-level quotes and two-way links
   * Document relationship diagram, global relationship diagram
   * Bookmark collection
* Use directly on the browser, support mobile-end
* Hierarchical tag
* Multi-window, multi-tab, drag and drop to split screen
* WebDAV
* Version mange and Git repository sync
* Fulltext search
* Themes and icons
   * Built-in bright and dark themes
   * Built-in two sets of icons, Material and Ant Design
   * Support custom themes and icons
* Export
   * Standard Markdown export
   * Content block quote provides anchor text + embedded Blockquote option
   * Copy to WeChat MP, Zhihu

## 🗺️ Roadmap

* [SiYuan development plan and progress](https://github.com/siyuan-note/siyuan/projects/1)
* [SiYuan Change logs](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 📸 Screenshots

### Instant Rendering

*Instant Rendering* mode should not be unfamiliar to users who are familiar with Typora. In theory, this is the most elegant Markdown editing method.

![vditor-ir](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/ir.gif)

### Roam

![roam.gif](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/roam.gif)

### Settings

![settings.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/settings.png)

### Search

![search.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/search.png)

### Block Reference

![blockref.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/block-ref.gif)

## 🛠️ Download Setup

* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [Gitee](https://gitee.com/siyuan-note/siyuan/releases)

## 📜 Documentation

* [SiYuan - A desktop Markdown Block-Reference and Bidirectional-Link note-taking application](https://ld246.com/article/1598872180233)
* [Markdown implements the exploration of block-level reference bidirectional links](https://ld246.com/article/1597226949061)

## 🏘️ Community

* [SiYuan Issues](https://github.com/siyuan-note/siyuan/issues)
* [SiYuan Forum](https://ld246.com/tag/siyuan)
* [SiYuan QQ Group](https://jq.qq.com/?_wv=1027&k=brIyNm7y)

## 🙏 Acknowledgement

* [Vditor - Browser-side Markdown editor](https://github.com/Vanessa219/vditor)
* [Lute - A structured Markdown engine that supports Go and JavaScript](https://github.com/88250/lute)
* [GoWebDAV - Go WebDAV client lib](https://github.com/88250/gowebdav)
* [Gulu - Go commons utilities](https://github.com/88250/gulu)
* [Gin - Go Web framework](https://github.com/gin-gonic/gin)
* [Melody - Go WebSocket framework](https://github.com/olahol/melody)
* [Electron - Build cross-platform desktop apps with JavaScript, HTML, and CSS](https://github.com/electron/electron)

==> v0.4.91.tar.gz: siyuan/README_en_US.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>When one drinks water, one must not forget where it comes from</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Release Date" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release-date/siyuan-note/siyuan.svg?style=flat-square&color=99CCFF"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README.md">中文</a>
</p>

## 💡 Introduction

SiYuan is a desktop Markdown Block-Reference and Bidirectional-Link note-taking application, supports Windows, Mac and Linux, can be used directly on the browser, and supports mobile-end adaptation.

Online experience: [https://ld246.com/xanadu/](https://ld246.com/xanadu/), welcome to [SiYuan Official Discussion Forum](https://ld246.com/tag/siyuan) to learn more.

![desktop.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/desktop.png)

![mobile.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/mobile.png)

## ✨  Features

* Born for Markdown
  * Instant Rendering editing mode similar to Typora
  * Support mathematical formulas, charts, flowcharts, Gantt charts, timing charts, staffs, etc.
  * Paste HTML automatically converted to Markdown
  * Configure Markdown to analyze detailed rendering parameters
* Content block
   * Block-level reference and two-way links
   * Document relationship diagram, global relationship diagram
   * Bookmark collection
   * Dynamic query embed
   * URL for browser visit or link with other software
* Use directly on the browser, support mobile-end
* Hierarchical tag
* Multi-window, multi-tab, drag and drop to split screen
* WebDAV
* Versioning and Sync
* Fulltext search
* Themes and icons
   * Built-in bright and dark themes
   * Built-in two sets of icons, Material and Ant Design
   * Support custom themes and icons
* Export
   * Standard Markdown export
   * Content block reference provides anchor text + embedded blockquote option
   * Copy to WeChat MP, Zhihu
* Online Cloud workspace
* Online Publishing and Share

## 🗺️ Roadmap

* [SiYuan development plan and progress](https://github.com/siyuan-note/siyuan/projects/1)
* [SiYuan Change logs](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 📸 Screenshots

### Instant Rendering

*Instant Rendering* mode should not be unfamiliar to users who are familiar with Typora. In theory, this is the most elegant Markdown editing method.

![vditor-ir](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/ir.gif)

### Roam

![roam.gif](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/roam.gif)

### Settings

![settings.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/settings.png)

### Search

![search.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/search.png)

### Block Reference

![blockref.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/block-ref.gif)

### Dynamic Query Embed

![block-query-embed.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/block-query-embed.png)

## 🛠️ Download Setup

* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [Gitee](https://gitee.com/siyuan-note/siyuan/releases)

## 📜 Documentation

* [SiYuan - A desktop Markdown Block-Reference and Bidirectional-Link note-taking application](https://ld246.com/article/1598872180233)
* [Markdown implements the exploration of block-level reference bidirectional links](https://ld246.com/article/1597226949061)

## 🏘️ Community

* [SiYuan Issues](https://github.com/siyuan-note/siyuan/issues)
* [SiYuan Forum](https://ld246.com/tag/siyuan)
* [SiYuan QQ Group](https://jq.qq.com/?_wv=1027&k=brIyNm7y)

## 🙏 Acknowledgement

* [Vditor - Browser-side Markdown editor](https://github.com/Vanessa219/vditor)
* [Lute - A structured Markdown engine that supports Go and JavaScript](https://github.com/88250/lute)
* [GoWebDAV - Go WebDAV client lib](https://github.com/88250/gowebdav)
* [Gulu - Go commons utilities](https://github.com/88250/gulu)
* [Melody - Go WebSocket framework](https://github.com/88250/melody)
* [Gin - Go Web framework](https://github.com/gin-gonic/gin)
* [Electron - Build cross-platform desktop apps with JavaScript, HTML, and CSS](https://github.com/electron/electron)
